Module cmap

Module cmap 

/ToUnicode map serialization / parsing

Structs

CidCMap
A code→CID CMap: the /Encoding of a composite (Type0) font (ISO 32000-1, 9.7.5). Where ToUnicodeCMap maps codes to text for extraction, this maps the raw content-stream bytes to codes (via the codespace ranges — codes may be 1–4 bytes, variable width!) and codes to CIDs (via cidrange/cidchar).
ToUnicodeCMap
The mapping from a CID to one or more Unicode code points.

Functions

get_to_unicode_cmap_from_font
Looks for a ToUnicode CMap entry on the dictionary, resolves it to a dictionary and parses the ToUnicodeCMap.