IccProfile

Struct IccProfile 

pub struct IccProfile {
    pub icc: Vec<u8>,
    pub icc_type: IccProfileType,
    pub has_alternate: bool,
    pub has_range: bool,
}
Icc profile

Fields

icc: Vec<u8>

Binary Icc profile

icc_type: IccProfileType

CMYK or RGB or LAB icc profile?

has_alternate: bool

Does the ICC profile have an “Alternate” version or not?

has_range: bool

Does the ICC profile have an “Range” dictionary Really not sure why this is needed, but this is needed on the documents Info dictionary

Implementations

Source

impl IccProfile

pub fn new(icc: Vec<u8>, icc_type: IccProfileType) -> Self

Creates a new Icc Profile

pub fn with_alternate_profile(self, has_alternate: bool) -> Self

Does the ICC profile have an alternate version (such as “DeviceCMYk”)?

pub fn with_range(self, has_range: bool) -> Self

Does the ICC profile have an “Range” dictionary?