pub fn printpdf_default_components() -> XmlComponentMapExpand description
Creates and returns a component map with all default HTML components registered
pub fn printpdf_default_components() -> XmlComponentMapCreates and returns a component map with all default HTML components registered