/ToUnicode map serialization / parsing
Structs
- CidCMap
- A code→CID CMap: the
/Encodingof a composite (Type0) font (ISO 32000-1, 9.7.5). WhereToUnicodeCMapmaps codes to text for extraction, this maps the raw content-stream bytes to codes (via the codespace ranges — codes may be 1–4 bytes, variable width!) and codes to CIDs (via cidrange/cidchar). - ToUnicodeC
Map - The mapping from a CID to one or more Unicode code points.
Functions
- get_
to_ unicode_ cmap_ from_ font - Looks for a
ToUnicodeCMap entry on the dictionary, resolves it to a dictionary and parses theToUnicodeCMap.