pub struct IccProfile {
pub icc: Vec<u8>,
pub icc_type: IccProfileType,
pub has_alternate: bool,
pub has_range: bool,
}Expand description
Icc profile
Fields
icc: Vec<u8>Binary Icc profile
icc_type: IccProfileTypeCMYK or RGB or LAB icc profile?
has_alternate: boolDoes the ICC profile have an “Alternate” version or not?
has_range: boolDoes the ICC profile have an “Range” dictionary Really not sure why this is needed, but this is needed on the documents Info dictionary
Implementations
Sourceimpl IccProfile
impl IccProfile
Sourcepub fn new(icc: Vec<u8>, icc_type: IccProfileType) -> Self
pub fn new(icc: Vec<u8>, icc_type: IccProfileType) -> Self
Creates a new Icc Profile
Sourcepub fn with_alternate_profile(self, has_alternate: bool) -> Self
pub fn with_alternate_profile(self, has_alternate: bool) -> Self
Does the ICC profile have an alternate version (such as “DeviceCMYk”)?
Sourcepub fn with_range(self, has_range: bool) -> Self
pub fn with_range(self, has_range: bool) -> Self
Does the ICC profile have an “Range” dictionary?