Module xobject

Module xobject 

XObject handling

Structs

ExternalStream
ExternalXObject
External XObject, invoked by /Do graphics operator
FormXObject
THIS IS NOT A PDF FORM! A form XObject can be nearly everything. PDF allows you to reuse content for the graphics stream in a FormXObject. A FormXObject is basically a layer-like content stream and can contain anything as long as it’s a valid strem. A FormXObject is intended to be used for reapeated content on one page.
GroupXObject
`/Type /Group`` (PDF reference section 4.9.2)
PostScriptXObject
TODO, very low priority
ReferenceXObject
PDF 1.4 and higher Contains a PDF file to be embedded in the current PDF
XObjectRotation
XObjectTransform
Transform that is applied immediately before the image gets painted. Does not affect anything other than the image.

Enums

DictItem
Simplified dict item for external streams
FormType
GroupXObjectType
ImageFilter
Describes the format the image bytes are compressed with.
XObject
External object that gets reference outside the PDF content stream Gets constructed similar to the ExtGState, then inserted into the /XObject dictionary on the page. You can instantiate XObjects with the /Do operator. The layer.add_xobject() (or better yet, the layer.add_image(), layer.add_form()) methods will do this for you.

Functions

build_dict