XObject handling
Structs
- External
Stream - ExternalX
Object - External XObject, invoked by
/Dographics operator - FormX
Object - THIS IS NOT A PDF FORM! A form
XObjectcan be nearly everything. PDF allows you to reuse content for the graphics stream in aFormXObject. AFormXObjectis basically a layer-like content stream and can contain anything as long as it’s a valid strem. AFormXObjectis intended to be used for reapeated content on one page. - GroupX
Object - `/Type /Group`` (PDF reference section 4.9.2)
- Post
ScriptX Object - TODO, very low priority
- ReferenceX
Object - PDF 1.4 and higher Contains a PDF file to be embedded in the current PDF
- XObject
Rotation - XObject
Transform - Transform that is applied immediately before the image gets painted. Does not affect anything other than the image.
Enums
- Dict
Item - Simplified dict item for external streams
- Form
Type - GroupX
Object Type - Image
Filter - Describes the format the image bytes are compressed with.
- XObject
- External object that gets reference outside the PDF content stream
Gets constructed similar to the
ExtGState, then inserted into the/XObjectdictionary on the page. You can instantiateXObjectswith the/Dooperator. Thelayer.add_xobject()(or better yet, thelayer.add_image(),layer.add_form()) methods will do this for you.